==> dif-database-repository-2.7.1-sources.jar: pt/digitalis/dif/dem/managers/impl/model/impl/ReportManagerServiceImpl.java <==
package pt.digitalis.dif.dem.managers.impl.model.impl;

import pt.digitalis.dif.model.hibernate.HibernateUtil;
import pt.digitalis.dif.model.dataset.IDataSet;
import pt.digitalis.dif.model.dataset.HibernateDataSet;
import pt.digitalis.dif.model.dataset.HibernateDataSetLegacyNoPK;
import pt.digitalis.utils.common.IBeanAttributes;

import pt.digitalis.dif.dem.managers.impl.model.DIFRepositoryFactory;
import pt.digitalis.dif.dem.managers.impl.model.IReportManagerService;
import pt.digitalis.dif.dem.managers.impl.model.data.SqlDataSource;
import pt.digitalis.dif.dem.managers.impl.model.data.ReportTemplate;
import pt.digitalis.dif.dem.managers.impl.model.data.ReportTemplateArea;
import pt.digitalis.dif.dem.managers.impl.model.data.ReportTemplateAreaTrans;
import pt.digitalis.dif.dem.managers.impl.model.data.ReportTemplateAreaSql;
import pt.digitalis.dif.dem.managers.impl.model.data.ReportInstanceDocument;
import pt.digitalis.dif.dem.managers.impl.model.data.ReportInstance;
import pt.digitalis.dif.dem.managers.impl.model.data.ReportInstanceArea;
import pt.digitalis.dif.dem.managers.impl.model.data.ReportInstanceAreaSql;
import pt.digitalis.dif.dem.managers.impl.model.data.ReportInstanceAreaTrans;
import pt.digitalis.dif.dem.managers.impl.model.data.JasperReportConfig;
import pt.digitalis.dif.dem.managers.impl.model.data.JasperReportLog;
import pt.digitalis.dif.dem.managers.impl.model.data.JasperReportTemplate;
import pt.digitalis.dif.dem.managers.impl.model.data.JasperReportTemplateFile;
import pt.digitalis.dif.dem.managers.impl.model.data.JasperReportTemplateParam;

/**
* NOTE: This file is auto generated and will be overwrite in a future file generation.
*/
public class ReportManagerServiceImpl implements IReportManagerService {

    /**
     * Obtains a new DataSet for the SqlDataSource entity
     *
     * @return A new HibernateDataSet instance
     */
    public HibernateDataSet<SqlDataSource> getSqlDataSourceDataSet() {
        return new HibernateDataSet<SqlDataSource>(SqlDataSource.class, HibernateUtil.getSessionFactory("DIFRepository"),
                SqlDataSource.getPKFieldListAsString(), SqlDataSource.FieldAttributes);
    }

    /**
     * Obtains a new DataSet for the ReportTemplate entity
     *
     * @return A new HibernateDataSet instance
     */
    public HibernateDataSet<ReportTemplate> getReportTemplateDataSet() {
        return new HibernateDataSet<ReportTemplate>(ReportTemplate.class, HibernateUtil.getSessionFactory("DIFRepository"),
                ReportTemplate.getPKFieldListAsString(), ReportTemplate.FieldAttributes);
    }

    /**
     * Obtains a new DataSet for the ReportTemplateArea entity
     *
     * @return A new HibernateDataSet instance
     */
    public HibernateDataSet<ReportTemplateArea> getReportTemplateAreaDataSet() {
        return new HibernateDataSet<ReportTemplateArea>(ReportTemplateArea.class, HibernateUtil.getSessionFactory("DIFRepository"),
                ReportTemplateArea.getPKFieldListAsString(), ReportTemplateArea.FieldAttributes);
    }

    /**
     * Obtains a new DataSet for the ReportTemplateAreaTrans entity
     *
     * @return A new HibernateDataSet instance
     */
    public HibernateDataSet<ReportTemplateAreaTrans> getReportTemplateAreaTransDataSet() {
        return new HibernateDataSet<ReportTemplateAreaTrans>(ReportTemplateAreaTrans.class, HibernateUtil.getSessionFactory("DIFRepository"),
                ReportTemplateAreaTrans.getPKFieldListAsString(), ReportTemplateAreaTrans.FieldAttributes);
    }

    /**
     * Obtains a new DataSet for the ReportTemplateAreaSql entity
     *
     * @return A new HibernateDataSet instance
     */
    public HibernateDataSet<ReportTemplateAreaSql> getReportTemplateAreaSqlDataSet() {
        return new HibernateDataSet<ReportTemplateAreaSql>(ReportTemplateAreaSql.class, HibernateUtil.getSessionFactory("DIFRepository"),
                ReportTemplateAreaSql.getPKFieldListAsString(), ReportTemplateAreaSql.FieldAttributes);
    }

    /**
     * Obtains a new DataSet for the ReportInstanceDocument entity
     *
     * @return A new HibernateDataSet instance
     */
    public HibernateDataSet<ReportInstanceDocument> getReportInstanceDocumentDataSet() {
        return new HibernateDataSet<ReportInstanceDocument>(ReportInstanceDocument.class, HibernateUtil.getSessionFactory("DIFRepository"),
                ReportInstanceDocument.getPKFieldListAsString(), ReportInstanceDocument.FieldAttributes);
    }

    /**
     * Obtains a new DataSet for the ReportInstance entity
     *
     * @return A new HibernateDataSet instance
     */
    public HibernateDataSet<ReportInstance> getReportInstanceDataSet() {
        return new HibernateDataSet<ReportInstance>(ReportInstance.class, HibernateUtil.getSessionFactory("DIFRepository"),
                ReportInstance.getPKFieldListAsString(), ReportInstance.FieldAttributes);
    }

    /**
     * Obtains a new DataSet for the ReportInstanceArea entity
     *
     * @return A new HibernateDataSet instance
     */
    public HibernateDataSet<ReportInstanceArea> getReportInstanceAreaDataSet() {
        return new HibernateDataSet<ReportInstanceArea>(ReportInstanceArea.class, HibernateUtil.getSessionFactory("DIFRepository"),
                ReportInstanceArea.getPKFieldListAsString(), ReportInstanceArea.FieldAttributes);
    }

    /**
     * Obtains a new DataSet for the ReportInstanceAreaSql entity
     *
     * @return A new HibernateDataSet instance
     */
    public HibernateDataSet<ReportInstanceAreaSql> getReportInstanceAreaSqlDataSet() {
        return new HibernateDataSet<ReportInstanceAreaSql>(ReportInstanceAreaSql.class, HibernateUtil.getSessionFactory("DIFRepository"),
                ReportInstanceAreaSql.getPKFieldListAsString(), ReportInstanceAreaSql.FieldAttributes);
    }

    /**
     * Obtains a new DataSet for the ReportInstanceAreaTrans entity
     *
     * @return A new HibernateDataSet instance
     */
    public HibernateDataSet<ReportInstanceAreaTrans> getReportInstanceAreaTransDataSet() {
        return new HibernateDataSet<ReportInstanceAreaTrans>(ReportInstanceAreaTrans.class, HibernateUtil.getSessionFactory("DIFRepository"),
                ReportInstanceAreaTrans.getPKFieldListAsString(), ReportInstanceAreaTrans.FieldAttributes);
    }

    /**
     * Obtains a new DataSet for the JasperReportConfig entity
     *
     * @return A new HibernateDataSet instance
     */
    public HibernateDataSet<JasperReportConfig> getJasperReportConfigDataSet() {
        return new HibernateDataSet<JasperReportConfig>(JasperReportConfig.class, HibernateUtil.getSessionFactory("DIFRepository"),
                JasperReportConfig.getPKFieldListAsString(), JasperReportConfig.FieldAttributes);
    }

    /**
     * Obtains a new DataSet for the JasperReportLog entity
     *
     * @return A new HibernateDataSet instance
     */
    public HibernateDataSet<JasperReportLog> getJasperReportLogDataSet() {
        return new HibernateDataSet<JasperReportLog>(JasperReportLog.class, HibernateUtil.getSessionFactory("DIFRepository"),
                JasperReportLog.getPKFieldListAsString(), JasperReportLog.FieldAttributes);
    }

    /**
     * Obtains a new DataSet for the JasperReportTemplate entity
     *
     * @return A new HibernateDataSet instance
     */
    public HibernateDataSet<JasperReportTemplate> getJasperReportTemplateDataSet() {
        return new HibernateDataSet<JasperReportTemplate>(JasperReportTemplate.class, HibernateUtil.getSessionFactory("DIFRepository"),
                JasperReportTemplate.getPKFieldListAsString(), JasperReportTemplate.FieldAttributes);
    }

    /**
     * Obtains a new DataSet for the JasperReportTemplateFile entity
     *
     * @return A new HibernateDataSet instance
     */
    public HibernateDataSet<JasperReportTemplateFile> getJasperReportTemplateFileDataSet() {
        return new HibernateDataSet<JasperReportTemplateFile>(JasperReportTemplateFile.class, HibernateUtil.getSessionFactory("DIFRepository"),
                JasperReportTemplateFile.getPKFieldListAsString(), JasperReportTemplateFile.FieldAttributes);
    }

    /**
     * Obtains a new DataSet for the JasperReportTemplateParam entity
     *
     * @return A new HibernateDataSet instance
     */
    public HibernateDataSet<JasperReportTemplateParam> getJasperReportTemplateParamDataSet() {
        return new HibernateDataSet<JasperReportTemplateParam>(JasperReportTemplateParam.class, HibernateUtil.getSessionFactory("DIFRepository"),
                JasperReportTemplateParam.getPKFieldListAsString(), JasperReportTemplateParam.FieldAttributes);
    }

    /**
     * Obtains a IDataSet for the given entity class
     *
     * @param clazz
     *            the entity class
     * @return A new IDataSet instance
     */
    public HibernateDataSet<? extends IBeanAttributes> getDataSet(Class<? extends IBeanAttributes> clazz) {

        if (clazz == SqlDataSource.class)
            return getSqlDataSourceDataSet();

        if (clazz == ReportTemplate.class)
            return getReportTemplateDataSet();

        if (clazz == ReportTemplateArea.class)
            return getReportTemplateAreaDataSet();

        if (clazz == ReportTemplateAreaTrans.class)
            return getReportTemplateAreaTransDataSet();

        if (clazz == ReportTemplateAreaSql.class)
            return getReportTemplateAreaSqlDataSet();

        if (clazz == ReportInstanceDocument.class)
            return getReportInstanceDocumentDataSet();

        if (clazz == ReportInstance.class)
            return getReportInstanceDataSet();

        if (clazz == ReportInstanceArea.class)
            return getReportInstanceAreaDataSet();

        if (clazz == ReportInstanceAreaSql.class)
            return getReportInstanceAreaSqlDataSet();

        if (clazz == ReportInstanceAreaTrans.class)
            return getReportInstanceAreaTransDataSet();

        if (clazz == JasperReportConfig.class)
            return getJasperReportConfigDataSet();

        if (clazz == JasperReportLog.class)
            return getJasperReportLogDataSet();

        if (clazz == JasperReportTemplate.class)
            return getJasperReportTemplateDataSet();

        if (clazz == JasperReportTemplateFile.class)
            return getJasperReportTemplateFileDataSet();

        if (clazz == JasperReportTemplateParam.class)
            return getJasperReportTemplateParamDataSet();

        return null;
    }

    /**
     * Obtains a IDataSet for the given entity class
     *
     * @param entityName
     *            the entity class simple name
     * @return A new IDataSet instance
     */
    public HibernateDataSet<? extends IBeanAttributes> getDataSet(String entityName) {

        if (entityName.equalsIgnoreCase(SqlDataSource.class.getSimpleName()))
            return getSqlDataSourceDataSet();

        if (entityName.equalsIgnoreCase(ReportTemplate.class.getSimpleName()))
            return getReportTemplateDataSet();

        if (entityName.equalsIgnoreCase(ReportTemplateArea.class.getSimpleName()))
            return getReportTemplateAreaDataSet();

        if (entityName.equalsIgnoreCase(ReportTemplateAreaTrans.class.getSimpleName()))
            return getReportTemplateAreaTransDataSet();

        if (entityName.equalsIgnoreCase(ReportTemplateAreaSql.class.getSimpleName()))
            return getReportTemplateAreaSqlDataSet();

        if (entityName.equalsIgnoreCase(ReportInstanceDocument.class.getSimpleName()))
            return getReportInstanceDocumentDataSet();

        if (entityName.equalsIgnoreCase(ReportInstance.class.getSimpleName()))
            return getReportInstanceDataSet();

        if (entityName.equalsIgnoreCase(ReportInstanceArea.class.getSimpleName()))
            return getReportInstanceAreaDataSet();

        if (entityName.equalsIgnoreCase(ReportInstanceAreaSql.class.getSimpleName()))
            return getReportInstanceAreaSqlDataSet();

        if (entityName.equalsIgnoreCase(ReportInstanceAreaTrans.class.getSimpleName()))
            return getReportInstanceAreaTransDataSet();

        if (entityName.equalsIgnoreCase(JasperReportConfig.class.getSimpleName()))
            return getJasperReportConfigDataSet();

        if (entityName.equalsIgnoreCase(JasperReportLog.class.getSimpleName()))
            return getJasperReportLogDataSet();

        if (entityName.equalsIgnoreCase(JasperReportTemplate.class.getSimpleName()))
            return getJasperReportTemplateDataSet();

        if (entityName.equalsIgnoreCase(JasperReportTemplateFile.class.getSimpleName()))
            return getJasperReportTemplateFileDataSet();

        if (entityName.equalsIgnoreCase(JasperReportTemplateParam.class.getSimpleName()))
            return getJasperReportTemplateParamDataSet();

        return null;
    }
}

==> dif-database-repository-2.7.3-5-sources.jar: pt/digitalis/dif/dem/managers/impl/model/impl/ReportManagerServiceImpl.java <==
package pt.digitalis.dif.dem.managers.impl.model.impl;

import pt.digitalis.dif.model.hibernate.HibernateUtil;
import pt.digitalis.dif.model.dataset.IDataSet;
import pt.digitalis.dif.model.dataset.HibernateDataSet;
import pt.digitalis.dif.model.dataset.HibernateDataSetLegacyNoPK;
import pt.digitalis.utils.common.IBeanAttributes;

import pt.digitalis.dif.dem.managers.impl.model.DIFRepositoryFactory;
import pt.digitalis.dif.dem.managers.impl.model.IReportManagerService;
import pt.digitalis.dif.dem.managers.impl.model.data.SqlDataSource;
import pt.digitalis.dif.dem.managers.impl.model.data.ReportTemplate;
import pt.digitalis.dif.dem.managers.impl.model.data.ReportTemplateArea;
import pt.digitalis.dif.dem.managers.impl.model.data.ReportTemplateAreaTrans;
import pt.digitalis.dif.dem.managers.impl.model.data.ReportTemplateAreaSql;
import pt.digitalis.dif.dem.managers.impl.model.data.ReportInstanceDocument;
import pt.digitalis.dif.dem.managers.impl.model.data.ReportInstance;
import pt.digitalis.dif.dem.managers.impl.model.data.ReportInstanceArea;
import pt.digitalis.dif.dem.managers.impl.model.data.ReportInstanceAreaSql;
import pt.digitalis.dif.dem.managers.impl.model.data.ReportInstanceAreaTrans;
import pt.digitalis.dif.dem.managers.impl.model.data.JasperReportConfig;
import pt.digitalis.dif.dem.managers.impl.model.data.JasperReportLog;
import pt.digitalis.dif.dem.managers.impl.model.data.JasperReportTemplate;
import pt.digitalis.dif.dem.managers.impl.model.data.JasperReportTemplateFile;
import pt.digitalis.dif.dem.managers.impl.model.data.JasperReportTemplateParam;

/**
* NOTE: This file is auto generated and will be overwrite in a future file generation.
*/
public class ReportManagerServiceImpl implements IReportManagerService {

    /**
     * Constant with the session factory ID
     */
    public static String SESSION_FACTORY_NAME = "DIFRepository";

    /**
     * Obtains a new DataSet for the SqlDataSource entity
     *
     * @return A new HibernateDataSet instance
     */
    public HibernateDataSet<SqlDataSource> getSqlDataSourceDataSet() {
        return new HibernateDataSet<SqlDataSource>(SqlDataSource.class, HibernateUtil.getSessionFactory(SESSION_FACTORY_NAME),
                SqlDataSource.getPKFieldListAsString(), SqlDataSource.FieldAttributes);
    }

    /**
     * Obtains a new DataSet for the ReportTemplate entity
     *
     * @return A new HibernateDataSet instance
     */
    public HibernateDataSet<ReportTemplate> getReportTemplateDataSet() {
        return new HibernateDataSet<ReportTemplate>(ReportTemplate.class, HibernateUtil.getSessionFactory(SESSION_FACTORY_NAME),
                ReportTemplate.getPKFieldListAsString(), ReportTemplate.FieldAttributes);
    }

    /**
     * Obtains a new DataSet for the ReportTemplateArea entity
     *
     * @return A new HibernateDataSet instance
     */
    public HibernateDataSet<ReportTemplateArea> getReportTemplateAreaDataSet() {
        return new HibernateDataSet<ReportTemplateArea>(ReportTemplateArea.class, HibernateUtil.getSessionFactory(SESSION_FACTORY_NAME),
                ReportTemplateArea.getPKFieldListAsString(), ReportTemplateArea.FieldAttributes);
    }

    /**
     * Obtains a new DataSet for the ReportTemplateAreaTrans entity
     *
     * @return A new HibernateDataSet instance
     */
    public HibernateDataSet<ReportTemplateAreaTrans> getReportTemplateAreaTransDataSet() {
        return new HibernateDataSet<ReportTemplateAreaTrans>(ReportTemplateAreaTrans.class, HibernateUtil.getSessionFactory(SESSION_FACTORY_NAME),
                ReportTemplateAreaTrans.getPKFieldListAsString(), ReportTemplateAreaTrans.FieldAttributes);
    }

    /**
     * Obtains a new DataSet for the ReportTemplateAreaSql entity
     *
     * @return A new HibernateDataSet instance
     */
    public HibernateDataSet<ReportTemplateAreaSql> getReportTemplateAreaSqlDataSet() {
        return new HibernateDataSet<ReportTemplateAreaSql>(ReportTemplateAreaSql.class, HibernateUtil.getSessionFactory(SESSION_FACTORY_NAME),
                ReportTemplateAreaSql.getPKFieldListAsString(), ReportTemplateAreaSql.FieldAttributes);
    }

    /**
     * Obtains a new DataSet for the ReportInstanceDocument entity
     *
     * @return A new HibernateDataSet instance
     */
    public HibernateDataSet<ReportInstanceDocument> getReportInstanceDocumentDataSet() {
        return new HibernateDataSet<ReportInstanceDocument>(ReportInstanceDocument.class, HibernateUtil.getSessionFactory(SESSION_FACTORY_NAME),
                ReportInstanceDocument.getPKFieldListAsString(), ReportInstanceDocument.FieldAttributes);
    }

    /**
     * Obtains a new DataSet for the ReportInstance entity
     *
     * @return A new HibernateDataSet instance
     */
    public HibernateDataSet<ReportInstance> getReportInstanceDataSet() {
        return new HibernateDataSet<ReportInstance>(ReportInstance.class, HibernateUtil.getSessionFactory(SESSION_FACTORY_NAME),
                ReportInstance.getPKFieldListAsString(), ReportInstance.FieldAttributes);
    }

    /**
     * Obtains a new DataSet for the ReportInstanceArea entity
     *
     * @return A new HibernateDataSet instance
     */
    public HibernateDataSet<ReportInstanceArea> getReportInstanceAreaDataSet() {
        return new HibernateDataSet<ReportInstanceArea>(ReportInstanceArea.class, HibernateUtil.getSessionFactory(SESSION_FACTORY_NAME),
                ReportInstanceArea.getPKFieldListAsString(), ReportInstanceArea.FieldAttributes);
    }

    /**
     * Obtains a new DataSet for the ReportInstanceAreaSql entity
     *
     * @return A new HibernateDataSet instance
     */
    public HibernateDataSet<ReportInstanceAreaSql> getReportInstanceAreaSqlDataSet() {
        return new HibernateDataSet<ReportInstanceAreaSql>(ReportInstanceAreaSql.class, HibernateUtil.getSessionFactory(SESSION_FACTORY_NAME),
                ReportInstanceAreaSql.getPKFieldListAsString(), ReportInstanceAreaSql.FieldAttributes);
    }

    /**
     * Obtains a new DataSet for the ReportInstanceAreaTrans entity
     *
     * @return A new HibernateDataSet instance
     */
    public HibernateDataSet<ReportInstanceAreaTrans> getReportInstanceAreaTransDataSet() {
        return new HibernateDataSet<ReportInstanceAreaTrans>(ReportInstanceAreaTrans.class, HibernateUtil.getSessionFactory(SESSION_FACTORY_NAME),
                ReportInstanceAreaTrans.getPKFieldListAsString(), ReportInstanceAreaTrans.FieldAttributes);
    }

    /**
     * Obtains a new DataSet for the JasperReportConfig entity
     *
     * @return A new HibernateDataSet instance
     */
    public HibernateDataSet<JasperReportConfig> getJasperReportConfigDataSet() {
        return new HibernateDataSet<JasperReportConfig>(JasperReportConfig.class, HibernateUtil.getSessionFactory(SESSION_FACTORY_NAME),
                JasperReportConfig.getPKFieldListAsString(), JasperReportConfig.FieldAttributes);
    }

    /**
     * Obtains a new DataSet for the JasperReportLog entity
     *
     * @return A new HibernateDataSet instance
     */
    public HibernateDataSet<JasperReportLog> getJasperReportLogDataSet() {
        return new HibernateDataSet<JasperReportLog>(JasperReportLog.class, HibernateUtil.getSessionFactory(SESSION_FACTORY_NAME),
                JasperReportLog.getPKFieldListAsString(), JasperReportLog.FieldAttributes);
    }

    /**
     * Obtains a new DataSet for the JasperReportTemplate entity
     *
     * @return A new HibernateDataSet instance
     */
    public HibernateDataSet<JasperReportTemplate> getJasperReportTemplateDataSet() {
        return new HibernateDataSet<JasperReportTemplate>(JasperReportTemplate.class, HibernateUtil.getSessionFactory(SESSION_FACTORY_NAME),
                JasperReportTemplate.getPKFieldListAsString(), JasperReportTemplate.FieldAttributes);
    }

    /**
     * Obtains a new DataSet for the JasperReportTemplateFile entity
     *
     * @return A new HibernateDataSet instance
     */
    public HibernateDataSet<JasperReportTemplateFile> getJasperReportTemplateFileDataSet() {
        return new HibernateDataSet<JasperReportTemplateFile>(JasperReportTemplateFile.class, HibernateUtil.getSessionFactory(SESSION_FACTORY_NAME),
                JasperReportTemplateFile.getPKFieldListAsString(), JasperReportTemplateFile.FieldAttributes);
    }

    /**
     * Obtains a new DataSet for the JasperReportTemplateParam entity
     *
     * @return A new HibernateDataSet instance
     */
    public HibernateDataSet<JasperReportTemplateParam> getJasperReportTemplateParamDataSet() {
        return new HibernateDataSet<JasperReportTemplateParam>(JasperReportTemplateParam.class, HibernateUtil.getSessionFactory(SESSION_FACTORY_NAME),
                JasperReportTemplateParam.getPKFieldListAsString(), JasperReportTemplateParam.FieldAttributes);
    }

    /**
     * Obtains a IDataSet for the given entity class
     *
     * @param clazz
     *            the entity class
     * @return A new IDataSet instance
     */
    public HibernateDataSet<? extends IBeanAttributes> getDataSet(Class<? extends IBeanAttributes> clazz) {

        if (clazz == SqlDataSource.class)
            return getSqlDataSourceDataSet();

        if (clazz == ReportTemplate.class)
            return getReportTemplateDataSet();

        if (clazz == ReportTemplateArea.class)
            return getReportTemplateAreaDataSet();

        if (clazz == ReportTemplateAreaTrans.class)
            return getReportTemplateAreaTransDataSet();

        if (clazz == ReportTemplateAreaSql.class)
            return getReportTemplateAreaSqlDataSet();

        if (clazz == ReportInstanceDocument.class)
            return getReportInstanceDocumentDataSet();

        if (clazz == ReportInstance.class)
            return getReportInstanceDataSet();

        if (clazz == ReportInstanceArea.class)
            return getReportInstanceAreaDataSet();

        if (clazz == ReportInstanceAreaSql.class)
            return getReportInstanceAreaSqlDataSet();

        if (clazz == ReportInstanceAreaTrans.class)
            return getReportInstanceAreaTransDataSet();

        if (clazz == JasperReportConfig.class)
            return getJasperReportConfigDataSet();

        if (clazz == JasperReportLog.class)
            return getJasperReportLogDataSet();

        if (clazz == JasperReportTemplate.class)
            return getJasperReportTemplateDataSet();

        if (clazz == JasperReportTemplateFile.class)
            return getJasperReportTemplateFileDataSet();

        if (clazz == JasperReportTemplateParam.class)
            return getJasperReportTemplateParamDataSet();

        return null;
    }

    /**
     * Obtains a IDataSet for the given entity class
     *
     * @param entityName
     *            the entity class simple name
     * @return A new IDataSet instance
     */
    public HibernateDataSet<? extends IBeanAttributes> getDataSet(String entityName) {

        if (entityName.equalsIgnoreCase(SqlDataSource.class.getSimpleName()))
            return getSqlDataSourceDataSet();

        if (entityName.equalsIgnoreCase(ReportTemplate.class.getSimpleName()))
            return getReportTemplateDataSet();

        if (entityName.equalsIgnoreCase(ReportTemplateArea.class.getSimpleName()))
            return getReportTemplateAreaDataSet();

        if (entityName.equalsIgnoreCase(ReportTemplateAreaTrans.class.getSimpleName()))
            return getReportTemplateAreaTransDataSet();

        if (entityName.equalsIgnoreCase(ReportTemplateAreaSql.class.getSimpleName()))
            return getReportTemplateAreaSqlDataSet();

        if (entityName.equalsIgnoreCase(ReportInstanceDocument.class.getSimpleName()))
            return getReportInstanceDocumentDataSet();

        if (entityName.equalsIgnoreCase(ReportInstance.class.getSimpleName()))
            return getReportInstanceDataSet();

        if (entityName.equalsIgnoreCase(ReportInstanceArea.class.getSimpleName()))
            return getReportInstanceAreaDataSet();

        if (entityName.equalsIgnoreCase(ReportInstanceAreaSql.class.getSimpleName()))
            return getReportInstanceAreaSqlDataSet();

        if (entityName.equalsIgnoreCase(ReportInstanceAreaTrans.class.getSimpleName()))
            return getReportInstanceAreaTransDataSet();

        if (entityName.equalsIgnoreCase(JasperReportConfig.class.getSimpleName()))
            return getJasperReportConfigDataSet();

        if (entityName.equalsIgnoreCase(JasperReportLog.class.getSimpleName()))
            return getJasperReportLogDataSet();

        if (entityName.equalsIgnoreCase(JasperReportTemplate.class.getSimpleName()))
            return getJasperReportTemplateDataSet();

        if (entityName.equalsIgnoreCase(JasperReportTemplateFile.class.getSimpleName()))
            return getJasperReportTemplateFileDataSet();

        if (entityName.equalsIgnoreCase(JasperReportTemplateParam.class.getSimpleName()))
            return getJasperReportTemplateParamDataSet();

        return null;
    }
}
